# Changelog

## 0.7.0 (2026-03-08)

Full Changelog: [v0.7.0-beta.5...v0.7.0](https://github.com/mirurobotics/python-platform-sdk/compare/v0.7.0-beta.5...v0.7.0)

### Features

* **api:** update to 2026-03-09.tetons ([568d158](https://github.com/mirurobotics/python-platform-sdk/commit/568d158f7af263ec6433e38bbd847643f4b77bf6))


### Chores

* **ci:** skip uploading artifacts on stainless-internal branches ([983e18f](https://github.com/mirurobotics/python-platform-sdk/commit/983e18ff19e0214adf95819a74e1fd50a3da7dae))

## 0.7.0-beta.5 (2026-03-06)

Full Changelog: [v0.7.0-beta.4...v0.7.0-beta.5](https://github.com/mirurobotics/python-platform-sdk/compare/v0.7.0-beta.4...v0.7.0-beta.5)

### Features

* **api:** manual updates ([e15b371](https://github.com/mirurobotics/python-platform-sdk/commit/e15b371d7a9a5687b9fbc60524a818c167cba97a))
* **api:** update to v2026-03-09.tetons-beta.2 spec ([1a97c7f](https://github.com/mirurobotics/python-platform-sdk/commit/1a97c7f1df22f5cfb6f5e4729af66630a50b3889))

## 0.7.0-beta.4 (2026-03-05)

Full Changelog: [v0.7.0-beta.3...v0.7.0-beta.4](https://github.com/mirurobotics/python-platform-sdk/compare/v0.7.0-beta.3...v0.7.0-beta.4)

### Bug Fixes

* pydantic model not being parsed on forward references ([5507c1c](https://github.com/mirurobotics/python-platform-sdk/commit/5507c1cc7c05c559a0f62e431005b472a7232796))

## 0.7.0-beta.3 (2026-03-05)

Full Changelog: [v0.7.0-beta.2...v0.7.0-beta.3](https://github.com/mirurobotics/python-platform-sdk/compare/v0.7.0-beta.2...v0.7.0-beta.3)

### Features

* **api:** manual updates ([7c6d61a](https://github.com/mirurobotics/python-platform-sdk/commit/7c6d61aa3d231a787539fbe62138a46de725ee81))

## 0.7.0-beta.2 (2026-03-05)

Full Changelog: [v0.0.2...v0.7.0-beta.2](https://github.com/mirurobotics/python-platform-sdk/compare/v0.0.2...v0.7.0-beta.2)

### Features

* **api:** manual updates ([80b0c17](https://github.com/mirurobotics/python-platform-sdk/commit/80b0c172dee57b78d5d1f2e17cd1283be0dc6740))
* **api:** manual updates ([187dcb1](https://github.com/mirurobotics/python-platform-sdk/commit/187dcb1e4878640fdf1792f69151714697ae89ed))


### Chores

* update example ([615100b](https://github.com/mirurobotics/python-platform-sdk/commit/615100b4fece75e73c1bdddd28d625db7590c509))
* update SDK settings ([b659dc5](https://github.com/mirurobotics/python-platform-sdk/commit/b659dc53534bf310a104987bd2ed3fefe325326e))
* update SDK settings ([5414e23](https://github.com/mirurobotics/python-platform-sdk/commit/5414e23d37776786c9366747cd909bd9851d5231))
* update SDK settings ([71e1217](https://github.com/mirurobotics/python-platform-sdk/commit/71e1217ae174784bda5e3c6052a3cdf70715b750))
* update SDK settings ([8006dd3](https://github.com/mirurobotics/python-platform-sdk/commit/8006dd38b8ce3cdaa2b66d6e8fdebf6f86d95205))
* update SDK settings ([c7d2a67](https://github.com/mirurobotics/python-platform-sdk/commit/c7d2a6715d15e3c535f1b3cc28f3fa9e01244eb4))
* update SDK settings ([60b9e0e](https://github.com/mirurobotics/python-platform-sdk/commit/60b9e0ed6f722e3569145eb5f31d726bf0ca6bc0))


### Refactors

* require miru version header in client initialization ([8e8e267](https://github.com/mirurobotics/python-platform-sdk/commit/8e8e267fe7c72da12c02b04da297bda9161055bb))

## 0.0.2 (2026-03-05)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/mirurobotics/python-platform-sdk/compare/v0.0.1...v0.0.2)

### Chores

* update SDK settings ([60b9e0e](https://github.com/mirurobotics/python-platform-sdk/commit/60b9e0ed6f722e3569145eb5f31d726bf0ca6bc0))
